==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/space/messages/ca/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Aquest espai encara està buit!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Aquest espai encara està buit!</b><br>Comença publicant alguna cosa...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Encara no sou membre d’aquest espai i encara no hi ha contingut públic! </b>',
    '<strong>About</strong> the Space' => '<strong>Sobre</strong> l\'espai',
    '<strong>About</strong> your membership' => '<strong>Quant a</strong> la vostra subscripció',
    '<strong>Invite</strong> members' => '<strong>Convida</strong> a membres',
    '<strong>New</strong> member request' => '<strong>Nova</strong> sol·licitud d\'unió',
    '<strong>New</strong> spaces' => '<strong>Nous</strong> espais',
    '<strong>Space</strong> followers' => '<strong>Seguidors</strong> de l\'espai',
    '<strong>Space</strong> members' => '<strong>Membres</strong> de l\'espai',
    '<strong>Space</strong> menu' => '<strong>Menú</strong> de l\'espai',
    'About' => 'Informació',
    'Accept' => 'Accepta',
    'Accept Invite' => 'Accepta la invitació',
    'Admin' => 'Administrador',
    'Administrator:' => 'Administrador:',
    'Administrators' => 'Administradors',
    'Application message' => 'Missatge d\'invitació',
    'Archived' => 'Arxivat',
    'As owner you cannot revoke your membership!' => 'Com a propietari no pots revocar la teva pertinença!',
    'Cancel' => 'Cancel·la',
    'Close' => 'Tanca',
    'Color' => 'Color',
    'Could not request membership!' => 'No s\'ha pogut crear la sol·licitud de pertinença!',
    'Created At' => 'Creat el',
    'Created By' => 'Creat per',
    'Decline' => 'No hi assistiré',
    'Decline Invite' => 'Rebutja la invitació',
    'Default' => 'Per defecte',
    'Default content visibility' => 'Visibilitat del contingut per defecte',
    'Delete' => 'Suprimeix',
    'Description' => 'Descripció',
    'Done' => 'Fet',
    'Email addresses' => 'Correus electrònics',
    'Everyone can enter' => 'Tothom hi pot entrar',
    'Follow' => 'Segueix',
    'Followers' => 'Seguidors',
    'Following' => 'Seguint',
    'Guests' => 'Convida',
    'Homepage' => 'Inici',
    'Homepage (Guests)' => 'Pàgina d\'inici (convidats)',
    'Invite' => 'Convida',
    'Invite and request' => 'Invitació i sol·licitud',
    'Invite by email' => 'Convida per correu electrònic',
    'Invites' => 'Convida',
    'Join Policy' => 'Políticia d\'admissió',
    'Last Visit' => 'Última visita',
    'Login' => 'Inici de sessió',
    'Max. 100 characters.' => 'Màx. 100 caràcters.',
    'Member since' => 'Membre des de',
    'Members' => 'Membres',
    'Moderator' => 'Moderador',
    'Moderator:' => 'Moderador:',
    'Moderators' => 'Moderadors',
    'My Space List' => 'La llista dels meus espais',
    'My space summary' => 'El meu resum de l\'espai',
    'Name' => 'Nom',
    'New user by e-mail (comma separated)' => 'Nou membre per correu electrònic (separat per comes)',
    'New user?' => 'Nou usuari?',
    'No spaces found.' => 'No s\'han trobat espais.',
    'Only by invite' => 'Només per invitació',
    'Owner' => 'Propietari',
    'Owner:' => 'Propietari:',
    'Pick users' => 'Tria usuaris',
    'Please shortly introduce yourself, to become a approved member of this workspace.' => 'Si us plau, presentat breument als administradors de l\'espai.',
    'Please shortly introduce yourself, to become an approved member of this space.' => 'Presenteu-vos breument per convertir-vos en membre aprovat d’aquest espai.',
    'Posts' => 'Publicacions',
    'Private' => 'Privat',
    'Private (Invisible)' => 'Privat (Invisible)',
    'Public' => 'Públic',
    'Public (Members & Guests)' => 'Públic (membres i convidats)',
    'Public (Members only)' => 'Públic (només per a membres)',
    'Public (Registered users only)' => 'Públic (només usuaris registrats)',
    'Request workspace membership' => 'Sol·licita unir-te',
    'Role' => 'Rol',
    'See all' => 'Veure tots',
    'Select all registered users' => 'Selecciona tots els usuaris registrats',
    'Send' => 'Envia',
    'Settings' => 'Configuració',
    'Settings could not be saved!' => 'No s\'ha pogut desar la configuració.',
    'Show all' => 'Mostra totes',
    'Sorting' => 'Ordena',
    'Space' => 'Espai',
    'Space Visibility' => 'Visibilitat de l\'espai',
    'Space directory' => 'Directori d\'espais',
    'Space is invisible!' => 'L\'espai és invisible!',
    'Spaces' => 'Espais',
    'Status' => 'Estat',
    'Stream' => 'Activitat',
    'Tags' => 'Etiquetes',
    'There is no pending invite!' => 'No hi ha invitacions pendents!',
    'This action is only available for workspace members!' => 'Aquesta acció només és vàlida per membres de l\'espai!',
    'This user is already a member of this space.' => 'Aquest usuari ja és membre d’aquest espai.',
    'This user is not a member of this space.' => 'Aquest usuari no és membre d’aquest espai.',
    'Updated At' => 'Actualitzat el',
    'Updated By' => 'Actualitzat per',
    'Updated by' => 'Actualitzat per',
    'User \'{username}\' is already a member of this space!' => 'L\'usuari "{username}" ja és membre d\'aquest espai.',
    'User invitations have been added to the queue' => 'S\'han afegit les invitacions d\'usuari a la cua',
    'User memberships have been added to the queue' => 'S\'han afegit les subscripcions dels membres a la cua',
    'User not found!' => 'Membre no trobat!',
    'Users' => 'Usuaris',
    'Users has been invited.' => 'Els usuaris han estat convidats.',
    'Visibility' => 'Visibilitat',
    'Visible for all (members and guests)' => 'Visible per a tots (membres i convidats)',
    'You are not allowed to join this space!' => 'No tens permís per unir-te a aquest espai!',
    'You cannot create private visible spaces!' => 'No pots crear espais privats!',
    'You cannot create public visible spaces!' => 'No pots crear espais públics!',
    'You need to login to view contents of this space!' => 'Heu d’iniciar sessió per veure el contingut d’aquest espai.',
    'Your request was successfully submitted to the workspace administrators.' => 'La teva sol·licitud d\'unió s\'ha enviat correctament als administradors de l\'espai.',
    '{count} members' => '{count} membres',
    '{email} is not valid!' => '{email} no vàlid!',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Request</strong> space membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Add users without invitation' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Do you really want to delete your profile image?' => '',
    'Do you really want to delete your title image?' => '',
    'Find Spaces by their description or by their tags' => '',
    'Hide Members sidebar in the stream page.' => '',
    'Join' => '',
    'Member' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Originator User ID' => '',
    'Pending' => '',
    'Request Message' => '',
    'Search...' => '',
    'Shown on About Page.' => '',
    'Sorry, you are not allowed to leave this space!' => '',
    'To invite users to this space, please type their names below to find and pick them.' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'Your request was successfully submitted to the space administrators.' => '',
];

==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/space/messages/ca/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Aquest espai encara està buit!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Aquest espai encara està buit!</b><br>Comença publicant alguna cosa...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Encara no sou membre d’aquest espai i encara no hi ha contingut públic! </b>',
    '<strong>About</strong> the Space' => '<strong>Sobre</strong> l\'espai',
    '<strong>About</strong> your membership' => '<strong>Quant a</strong> la vostra subscripció',
    '<strong>Invite</strong> members' => '<strong>Convida</strong> a membres',
    '<strong>New</strong> member request' => '<strong>Nova</strong> sol·licitud d\'unió',
    '<strong>New</strong> spaces' => '<strong>Nous</strong> espais',
    '<strong>Space</strong> followers' => '<strong>Seguidors</strong> de l\'espai',
    '<strong>Space</strong> members' => '<strong>Membres</strong> de l\'espai',
    '<strong>Space</strong> menu' => '<strong>Menú</strong> de l\'espai',
    'About' => 'Informació',
    'Accept' => 'Accepta',
    'Accept Invite' => 'Accepta la invitació',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Presenteu-vos breument per convertir-vos en membre aprovat d’aquest espai.',
    'Admin' => 'Administrador',
    'Administrator:' => 'Administrador:',
    'Administrators' => 'Administradors',
    'Archived' => 'Arxivat',
    'As owner you cannot revoke your membership!' => 'Com a propietari no pots revocar la teva pertinença!',
    'Cancel' => 'Cancel·la',
    'Close' => 'Tanca',
    'Color' => 'Color',
    'Could not request membership!' => 'No s\'ha pogut crear la sol·licitud de pertinença!',
    'Created At' => 'Creat el',
    'Created By' => 'Creat per',
    'Decline' => 'No hi assistiré',
    'Decline Invite' => 'Rebutja la invitació',
    'Default' => 'Per defecte',
    'Default content visibility' => 'Visibilitat del contingut per defecte',
    'Delete' => 'Suprimeix',
    'Description' => 'Descripció',
    'Done' => 'Fet',
    'Email addresses' => 'Correus electrònics',
    'Everyone can enter' => 'Tothom hi pot entrar',
    'Follow' => 'Segueix',
    'Followers' => 'Seguidors',
    'Following' => 'Seguint',
    'Guests' => 'Convida',
    'Homepage' => 'Inici',
    'Homepage (Guests)' => 'Pàgina d\'inici (convidats)',
    'Invite' => 'Convida',
    'Invite and request' => 'Invitació i sol·licitud',
    'Invite by email' => 'Convida per correu electrònic',
    'Invites' => 'Convida',
    'Join Policy' => 'Políticia d\'admissió',
    'Last Visit' => 'Última visita',
    'Login' => 'Inici de sessió',
    'Max. 100 characters.' => 'Màx. 100 caràcters.',
    'Member since' => 'Membre des de',
    'Members' => 'Membres',
    'Moderator' => 'Moderador',
    'Moderator:' => 'Moderador:',
    'Moderators' => 'Moderadors',
    'My Space List' => 'La llista dels meus espais',
    'My space summary' => 'El meu resum de l\'espai',
    'Name' => 'Nom',
    'New user by e-mail (comma separated)' => 'Nou membre per correu electrònic (separat per comes)',
    'New user?' => 'Nou usuari?',
    'No spaces found.' => 'No s\'han trobat espais.',
    'Only by invite' => 'Només per invitació',
    'Owner' => 'Propietari',
    'Owner:' => 'Propietari:',
    'Pick users' => 'Tria usuaris',
    'Posts' => 'Publicacions',
    'Private' => 'Privat',
    'Private (Invisible)' => 'Privat (Invisible)',
    'Public' => 'Públic',
    'Public (Members & Guests)' => 'Públic (membres i convidats)',
    'Public (Members only)' => 'Públic (només per a membres)',
    'Public (Registered users only)' => 'Públic (només usuaris registrats)',
    'Role' => 'Rol',
    'See all' => 'Veure tots',
    'Select all registered users' => 'Selecciona tots els usuaris registrats',
    'Send' => 'Envia',
    'Settings' => 'Configuració',
    'Settings could not be saved!' => 'No s\'ha pogut desar la configuració.',
    'Show all' => 'Mostra totes',
    'Sorting' => 'Ordena',
    'Space' => 'Espai',
    'Space Visibility' => 'Visibilitat de l\'espai',
    'Space directory' => 'Directori d\'espais',
    'Space is invisible!' => 'L\'espai és invisible!',
    'Spaces' => 'Espais',
    'Status' => 'Estat',
    'Stream' => 'Activitat',
    'Tags' => 'Etiquetes',
    'There is no pending invite!' => 'No hi ha invitacions pendents!',
    'This action is only available for workspace members!' => 'Aquesta acció només és vàlida per membres de l\'espai!',
    'This user is already a member of this space.' => 'Aquest usuari ja és membre d’aquest espai.',
    'This user is not a member of this space.' => 'Aquest usuari no és membre d’aquest espai.',
    'Updated At' => 'Actualitzat el',
    'Updated By' => 'Actualitzat per',
    'Updated by' => 'Actualitzat per',
    'User \'{username}\' is already a member of this space!' => 'L\'usuari "{username}" ja és membre d\'aquest espai.',
    'User invitations have been added to the queue' => 'S\'han afegit les invitacions d\'usuari a la cua',
    'User memberships have been added to the queue' => 'S\'han afegit les subscripcions dels membres a la cua',
    'User not found!' => 'Membre no trobat!',
    'Users' => 'Usuaris',
    'Users has been invited.' => 'Els usuaris han estat convidats.',
    'Visibility' => 'Visibilitat',
    'Visible for all (members and guests)' => 'Visible per a tots (membres i convidats)',
    'You are not allowed to join this space!' => 'No tens permís per unir-te a aquest espai!',
    'You cannot create private visible spaces!' => 'No pots crear espais privats!',
    'You cannot create public visible spaces!' => 'No pots crear espais públics!',
    'You need to login to view contents of this space!' => 'Heu d’iniciar sessió per veure el contingut d’aquest espai.',
    'Your Message' => 'Missatge d\'invitació',
    '{count} members' => '{count} membres',
    '{email} is not valid!' => '{email} no vàlid!',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Request</strong> Membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Add users without invitation' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Do you really want to delete your profile image?' => '',
    'Do you really want to delete your title image?' => '',
    'Find Spaces by their description or by their tags' => '',
    'Hide Members sidebar in the stream page.' => '',
    'I want to become a member because...' => '',
    'Join' => '',
    'Member' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Originator User ID' => '',
    'Pending' => '',
    'Request Message' => '',
    'Search...' => '',
    'Shown on About Page.' => '',
    'Sorry, you are not allowed to leave this space!' => '',
    'To invite users to this space, please type their names below to find and pick them.' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'Your request was successfully submitted to the space administrators.' => '',
];
